realalg: For manipulating real algebraic numbers
================================================

Description
-----------

For manipulating real algebraic numbers

License
-------

MIT License

Upstream Contact
----------------

https://pypi.org/project/realalg/

